==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceCorsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class FhirServiceCorsConfigurationArgs(
    public val allowCredentials: Output<Boolean>? = null,
    public val headers: Output<List<String>>? = null,
    public val maxAge: Output<Int>? = null,
    public val methods: Output<List<String>>? = null,
    public val origins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder()
            .allowCredentials(allowCredentials?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maxAge(maxAge?.applyValue({ args0 -> args0 }))
            .methods(methods?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .origins(origins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FhirServiceCorsConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceCorsConfigurationArgsBuilder internal constructor() {
    private var allowCredentials: Output<Boolean>? = null

    private var headers: Output<List<String>>? = null

    private var maxAge: Output<Int>? = null

    private var methods: Output<List<String>>? = null

    private var origins: Output<List<String>>? = null

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("oigcidkhpcbyuicm")
    public suspend fun allowCredentials(`value`: Output<Boolean>) {
        this.allowCredentials = value
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("kciogpetlrwpuweu")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("fshfumxshbplabfh")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("fxpiswexwaiqawcj")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("bvwvcmoaopxhvpep")
    public suspend fun maxAge(`value`: Output<Int>) {
        this.maxAge = value
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("ogufdfekcysarucy")
    public suspend fun methods(`value`: Output<List<String>>) {
        this.methods = value
    }

    @JvmName("wkbrbrtnclbatauh")
    public suspend fun methods(vararg values: Output<String>) {
        this.methods = Output.all(values.asList())
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("plerasvofvkjacvy")
    public suspend fun methods(values: List<Output<String>>) {
        this.methods = Output.all(values)
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("reylvydgnicumjra")
    public suspend fun origins(`value`: Output<List<String>>) {
        this.origins = value
    }

    @JvmName("gqeycmvdthtugggu")
    public suspend fun origins(vararg values: Output<String>) {
        this.origins = Output.all(values.asList())
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("mhrrcjtxisptojgp")
    public suspend fun origins(values: List<Output<String>>) {
        this.origins = Output.all(values)
    }

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("ksoyslglyfcoqnjq")
    public suspend fun allowCredentials(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowCredentials = mapped
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("vqtvxqcmnccdfkpe")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("oxhhcrclcrxwalta")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("oghxcxwgatggmnpv")
    public suspend fun maxAge(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxAge = mapped
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("pewhqhliimqxbvly")
    public suspend fun methods(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("hhhrvdrnfjohughu")
    public suspend fun methods(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("ofcagecshjrijvtg")
    public suspend fun origins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("fshmnabegimubwvu")
    public suspend fun origins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    internal fun build(): FhirServiceCorsConfigurationArgs = FhirServiceCorsConfigurationArgs(
        allowCredentials = allowCredentials,
        headers = headers,
        maxAge = maxAge,
        methods = methods,
        origins = origins,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceCorsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The settings for the CORS configuration of the service instance.
 * @property allowCredentials If credentials are allowed via CORS.
 * @property headers The headers to be allowed via CORS.
 * @property maxAge The max age to be allowed via CORS.
 * @property methods The methods to be allowed via CORS.
 * @property origins The origins to be allowed via CORS.
 */
public data class FhirServiceCorsConfigurationArgs(
    public val allowCredentials: Output<Boolean>? = null,
    public val headers: Output<List<String>>? = null,
    public val maxAge: Output<Int>? = null,
    public val methods: Output<List<String>>? = null,
    public val origins: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceCorsConfigurationArgs.builder()
            .allowCredentials(allowCredentials?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maxAge(maxAge?.applyValue({ args0 -> args0 }))
            .methods(methods?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .origins(origins?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FhirServiceCorsConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceCorsConfigurationArgsBuilder internal constructor() {
    private var allowCredentials: Output<Boolean>? = null

    private var headers: Output<List<String>>? = null

    private var maxAge: Output<Int>? = null

    private var methods: Output<List<String>>? = null

    private var origins: Output<List<String>>? = null

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("ibkanommkcfhmpmc")
    public suspend fun allowCredentials(`value`: Output<Boolean>) {
        this.allowCredentials = value
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("hpfjstsajjfagkeg")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("kbgscqrfqywopsgj")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("dhrjkwdpomnhgmag")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("qadadnryleipwjjp")
    public suspend fun maxAge(`value`: Output<Int>) {
        this.maxAge = value
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("olvcvreokmcxblvh")
    public suspend fun methods(`value`: Output<List<String>>) {
        this.methods = value
    }

    @JvmName("clvypscfteftekpn")
    public suspend fun methods(vararg values: Output<String>) {
        this.methods = Output.all(values.asList())
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("mixuhqoacnsftdry")
    public suspend fun methods(values: List<Output<String>>) {
        this.methods = Output.all(values)
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("tudqitdaxbsgusyu")
    public suspend fun origins(`value`: Output<List<String>>) {
        this.origins = value
    }

    @JvmName("anbrmbaeurlbggef")
    public suspend fun origins(vararg values: Output<String>) {
        this.origins = Output.all(values.asList())
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("koinrebkktmteonc")
    public suspend fun origins(values: List<Output<String>>) {
        this.origins = Output.all(values)
    }

    /**
     * @param value If credentials are allowed via CORS.
     */
    @JvmName("cwflgtmhodysxmjx")
    public suspend fun allowCredentials(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowCredentials = mapped
    }

    /**
     * @param value The headers to be allowed via CORS.
     */
    @JvmName("sbgrnquknbyixnqm")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values The headers to be allowed via CORS.
     */
    @JvmName("tdaavjgaksgmgdgl")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value The max age to be allowed via CORS.
     */
    @JvmName("yjeawngjhlmotkct")
    public suspend fun maxAge(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxAge = mapped
    }

    /**
     * @param value The methods to be allowed via CORS.
     */
    @JvmName("gtorkdhafspceeqn")
    public suspend fun methods(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param values The methods to be allowed via CORS.
     */
    @JvmName("utegckordjtuwavd")
    public suspend fun methods(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.methods = mapped
    }

    /**
     * @param value The origins to be allowed via CORS.
     */
    @JvmName("vkigotgmwobxwfda")
    public suspend fun origins(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    /**
     * @param values The origins to be allowed via CORS.
     */
    @JvmName("mnobwohkmhqorlcr")
    public suspend fun origins(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.origins = mapped
    }

    internal fun build(): FhirServiceCorsConfigurationArgs = FhirServiceCorsConfigurationArgs(
        allowCredentials = allowCredentials,
        headers = headers,
        maxAge = maxAge,
        methods = methods,
        origins = origins,
    )
}
